# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog],
and this project adheres to [Semantic Versioning].

[Keep a Changelog]: https://keepachangelog.com/en/1.0.0
[Semantic Versioning]: https://semver.org/spec/v2.0.0.html

## [v3.3.0](https://github.com/dotenv-linter/dotenv-linter/releases/tag/v3.3.0) - 2022-12-24

### Features

- Add check for values that require surrounding quotes ([#521](https://github.com/dotenv-linter/dotenv-linter/pull/521))

### Fixes

- Check that tag is valid semver ([#556](https://github.com/dotenv-linter/dotenv-linter/pull/556))
- Don't remove quotes for values containing hash-sign ([#560](https://github.com/dotenv-linter/dotenv-linter/pull/560))

### CI

- Fix arm docker build ([#609](https://github.com/dotenv-linter/dotenv-linter/pull/609))
- Replace `actions-rs/toolchain` with `dtolnay/rust-toolchain` ([#573](https://github.com/dotenv-linter/dotenv-linter/pull/573))
- Add docker arm64 image ([#533](https://github.com/dotenv-linter/dotenv-linter/pull/533))
- Fix release builds ([#531](https://github.com/dotenv-linter/dotenv-linter/pull/531))
- Add job to check release builds ([#529](https://github.com/dotenv-linter/dotenv-linter/pull/529))
- Add dprint and lychee actions + ci optimization ([#503](https://github.com/dotenv-linter/dotenv-linter/pull/503))
- Add `stale` action ([#483](https://github.com/dotenv-linter/dotenv-linter/pull/483))
- Fix release ([#465](https://github.com/dotenv-linter/dotenv-linter/pull/465))

### Documentation

- Add commit standard for the CONTRIBUTION file ([#561](https://github.com/dotenv-linter/dotenv-linter/pull/561))
- Update readme ([#543](https://github.com/dotenv-linter/dotenv-linter/pull/543))
- Fix links in `CHANGELOG.md` ([#536](https://github.com/dotenv-linter/dotenv-linter/pull/536))

### Miscellaneous Tasks

- Use `Box::<T>::default()` instead of `Box::new(T::default())` ([#605](https://github.com/dotenv-linter/dotenv-linter/pull/605))
- Fix clippy warning ([#585](https://github.com/dotenv-linter/dotenv-linter/pull/585))
- Generate a changelog and update release process ([#544](https://github.com/dotenv-linter/dotenv-linter/pull/544))
- Update `criterion-compare` action ([#484](https://github.com/dotenv-linter/dotenv-linter/pull/484))
- Update `cargo-deny` config ([#481](https://github.com/dotenv-linter/dotenv-linter/pull/481))
- Clippy warnings ([#480](https://github.com/dotenv-linter/dotenv-linter/pull/480))
- Add dependabot ([#472](https://github.com/dotenv-linter/dotenv-linter/pull/472))

### Refactor

- Move CLI commands to separate functions ([#489](https://github.com/dotenv-linter/dotenv-linter/pull/489))
- Check ci with all-targets arg ([#488](https://github.com/dotenv-linter/dotenv-linter/pull/488))
- Usage of fix and compare ([#486](https://github.com/dotenv-linter/dotenv-linter/pull/486))
- Skip_checks with use default iterator ([#482](https://github.com/dotenv-linter/dotenv-linter/pull/482))

### Testing

- Add tests to verify cli application ([#490](https://github.com/dotenv-linter/dotenv-linter/pull/490))

### Update dependencies

- Bump actions/stale from 6 to 7 ([#607](https://github.com/dotenv-linter/dotenv-linter/pull/607))
- Bump update-informer from 0.5.0 to 0.6.0 ([#603](https://github.com/dotenv-linter/dotenv-linter/pull/603))
- Bump wagoid/commitlint-github-action from 5.2.2 to 5.3.0 ([#595](https://github.com/dotenv-linter/dotenv-linter/pull/595))
- Bump Swatinem/rust-cache from 2.1.0 to 2.2.0 ([#588](https://github.com/dotenv-linter/dotenv-linter/pull/588))
- Bump lycheeverse/lychee-action from 1.5.3 to 1.5.4 ([#587](https://github.com/dotenv-linter/dotenv-linter/pull/587))
- Bump lycheeverse/lychee-action from 1.5.2 to 1.5.3 ([#586](https://github.com/dotenv-linter/dotenv-linter/pull/586))
- Bump Swatinem/rust-cache from 2.0.1 to 2.1.0 ([#582](https://github.com/dotenv-linter/dotenv-linter/pull/582))
- Bump lycheeverse/lychee-action from 1.5.1 to 1.5.2 ([#583](https://github.com/dotenv-linter/dotenv-linter/pull/583))
- Bump wagoid/commitlint-github-action from 5.2.0 to 5.2.2 ([#581](https://github.com/dotenv-linter/dotenv-linter/pull/581))
- Bump boa-dev/criterion-compare-action from 3.2.3 to 3.2.4 ([#580](https://github.com/dotenv-linter/dotenv-linter/pull/580))
- Bump assert_cmd from 2.0.4 to 2.0.5 ([#578](https://github.com/dotenv-linter/dotenv-linter/pull/578))
- Bump criterion from 0.3.6 to 0.4.0 ([#575](https://github.com/dotenv-linter/dotenv-linter/pull/575))
- Bump Swatinem/rust-cache from 2.0.0 to 2.0.1 ([#571](https://github.com/dotenv-linter/dotenv-linter/pull/571))
- Bump dunce from 1.0.2 to 1.0.3 ([#564](https://github.com/dotenv-linter/dotenv-linter/pull/564))
- Bump wagoid/commitlint-github-action from 5.0.2 to 5.2.0 ([#565](https://github.com/dotenv-linter/dotenv-linter/pull/565))
- Bump boa-dev/criterion-compare-action from 3.2.2 to 3.2.3 ([#570](https://github.com/dotenv-linter/dotenv-linter/pull/570))
- Bump actions/stale from 5 to 6 ([#552](https://github.com/dotenv-linter/dotenv-linter/pull/552))
- Bump lycheeverse/lychee-action from 1.5.0 to 1.5.1 ([#538](https://github.com/dotenv-linter/dotenv-linter/pull/538))
- Bump Swatinem/rust-cache from 1.4.0 to 2.0.0 ([#534](https://github.com/dotenv-linter/dotenv-linter/pull/534))
- Bump dprint/check from 2.0 to 2.1 ([#535](https://github.com/dotenv-linter/dotenv-linter/pull/535))
- Bump criterion from 0.3.5 to 0.3.6 ([#532](https://github.com/dotenv-linter/dotenv-linter/pull/532))
- Bump wagoid/commitlint-github-action from 5.0.1 to 5.0.2 ([#530](https://github.com/dotenv-linter/dotenv-linter/pull/530))
- Bump Swatinem/rust-cache from 1.3.0 to 1.4.0 ([#528](https://github.com/dotenv-linter/dotenv-linter/pull/528))
- Bump actions/cache from 3.0.2 to 3.0.4 ([#522](https://github.com/dotenv-linter/dotenv-linter/pull/522))
- Bump boa-dev/criterion-compare-action from 3.2.1 to 3.2.2 ([#518](https://github.com/dotenv-linter/dotenv-linter/pull/518))
- Bump regex from 1.5.4 to 1.5.6 ([#520](https://github.com/dotenv-linter/dotenv-linter/pull/520))
- Bump crossbeam-utils from 0.8.5 to 0.8.8 ([#519](https://github.com/dotenv-linter/dotenv-linter/pull/519))
- Bump wagoid/commitlint-github-action from 4.1.11 to 5.0.1 ([#527](https://github.com/dotenv-linter/dotenv-linter/pull/527))
- Bump boa-dev/criterion-compare-action from 3.2.0 to 3.2.1 ([#509](https://github.com/dotenv-linter/dotenv-linter/pull/509))
- Bump clap from 3.1.9 to 3.1.10 ([#506](https://github.com/dotenv-linter/dotenv-linter/pull/506))
- Bump clap from 3.1.8 to 3.1.9 ([#505](https://github.com/dotenv-linter/dotenv-linter/pull/505))
- Bump actions/stale from 4 to 5 ([#502](https://github.com/dotenv-linter/dotenv-linter/pull/502))
- Bump actions/cache from 3.0.1 to 3.0.2 ([#501](https://github.com/dotenv-linter/dotenv-linter/pull/501))
- Bump codecov/codecov-action from 2.1.0 to 3 ([#499](https://github.com/dotenv-linter/dotenv-linter/pull/499))
- Bump wagoid/commitlint-github-action from 4.1.10 to 4.1.11 ([#500](https://github.com/dotenv-linter/dotenv-linter/pull/500))
- Bump clap from 3.1.6 to 3.1.8 ([#497](https://github.com/dotenv-linter/dotenv-linter/pull/497))
- Bump wagoid/commitlint-github-action from 4.1.9 to 4.1.10 ([#495](https://github.com/dotenv-linter/dotenv-linter/pull/495))
- Bump actions/cache from 3.0.0 to 3.0.1 ([#494](https://github.com/dotenv-linter/dotenv-linter/pull/494))
- Update dependency `update-informer` ([#493](https://github.com/dotenv-linter/dotenv-linter/pull/493))
- Bump actions/cache from 2 to 3.0.0 ([#491](https://github.com/dotenv-linter/dotenv-linter/pull/491))
- Update `clap` ([#485](https://github.com/dotenv-linter/dotenv-linter/pull/485))
- Bump wagoid/commitlint-github-action from 2 to 4.1.9 ([#473](https://github.com/dotenv-linter/dotenv-linter/pull/473))
- Bump actions/checkout from 1 to 3 ([#474](https://github.com/dotenv-linter/dotenv-linter/pull/474))
- Bump codecov/codecov-action from 1 to 2.1.0 ([#475](https://github.com/dotenv-linter/dotenv-linter/pull/475))
- Bump tempfile from 3.2.0 to 3.3.0 ([#478](https://github.com/dotenv-linter/dotenv-linter/pull/478))
- Bump assert_cmd from 2.0.2 to 2.0.4 ([#479](https://github.com/dotenv-linter/dotenv-linter/pull/479))
- Bump update-informer from 0.3.0 to 0.4.0 ([#477](https://github.com/dotenv-linter/dotenv-linter/pull/477))
- Update dependency `update-informer` ([#470](https://github.com/dotenv-linter/dotenv-linter/pull/470))

## [v3.2.0] - 2022-01-24

### 🚀 Added

- Add check for new version [#454] ([@mgrachev](https://github.com/mgrachev))
- Support of double-quoted multiline values [#453] ([@DDtKey](https://github.com/DDtKey))
- Support of single-quoted multiline values [#450] ([@DDtKey](https://github.com/DDtKey))

### 🔧 Changed

- Update `cargo-deny` config [#459] ([@mgrachev](https://github.com/mgrachev))
- Update docker build [#456] ([@mgrachev](https://github.com/mgrachev))
- Update dependencies [#455] ([@mgrachev](https://github.com/mgrachev))
- Use derive (default) instead of impl [#452] ([@mgrachev](https://github.com/mgrachev))
- Get rid of `Rc<FileEntry>` in `LineEntry` [#448] ([@mgrachev](https://github.com/mgrachev))
- Replace `LineEntry` with line number in `Warning` [#447] ([@mgrachev](https://github.com/mgrachev))
- Tidy up imports [#446] ([@mgrachev](https://github.com/mgrachev))
- Add type alias for `Result` [#445] ([@mgrachev](https://github.com/mgrachev))
- Change edition to 2021 [#444] ([@mgrachev](https://github.com/mgrachev))
- Display a message on installation error [#443] ([@mgrachev](https://github.com/mgrachev))
- Fix falling on checking multi-line values [#462] ([@DDtKey](https://github.com/DDtKey))
- Detect multi-line values if they contain a `=` sign [#463] ([@DDtKey](https://github.com/DDtKey))

[#463]: https://github.com/dotenv-linter/dotenv-linter/pull/463
[#462]: https://github.com/dotenv-linter/dotenv-linter/pull/462
[#459]: https://github.com/dotenv-linter/dotenv-linter/pull/459
[#456]: https://github.com/dotenv-linter/dotenv-linter/pull/456
[#455]: https://github.com/dotenv-linter/dotenv-linter/pull/455
[#454]: https://github.com/dotenv-linter/dotenv-linter/pull/454
[#453]: https://github.com/dotenv-linter/dotenv-linter/pull/453
[#452]: https://github.com/dotenv-linter/dotenv-linter/pull/452
[#450]: https://github.com/dotenv-linter/dotenv-linter/pull/450
[#448]: https://github.com/dotenv-linter/dotenv-linter/pull/448
[#447]: https://github.com/dotenv-linter/dotenv-linter/pull/447
[#446]: https://github.com/dotenv-linter/dotenv-linter/pull/446
[#445]: https://github.com/dotenv-linter/dotenv-linter/pull/445
[#444]: https://github.com/dotenv-linter/dotenv-linter/pull/444
[#443]: https://github.com/dotenv-linter/dotenv-linter/pull/443

## [v3.1.1] - 2021-08-25

### 🚀 Added

- `aarch64` support (mac, linux, win) [#436] ([@DDtKey](https://github.com/DDtKey))

### 🔧 Changed

- Fix clippy warnings [#437] ([@mgrachev](https://github.com/mgrachev))
- Use enum instead of string for lint's identity [#427] ([@fabricio7p](https://github.com/fabricio7p))
- Get rid of the name field in checks and fixes structs [#432] ([@mgrachev](https://github.com/mgrachev))
- Replace filter with unwrap on flatten [#434] ([@Fcukit](https://github.com/Fcukit))

[#437]: https://github.com/dotenv-linter/dotenv-linter/pull/437
[#436]: https://github.com/dotenv-linter/dotenv-linter/pull/436
[#434]: https://github.com/dotenv-linter/dotenv-linter/pull/434
[#432]: https://github.com/dotenv-linter/dotenv-linter/pull/432
[#427]: https://github.com/dotenv-linter/dotenv-linter/pull/427

## [v3.1.0] - 2021-06-09

### 🚀 Added

- Add fixer: Substitution Key [#428] ([@DDtKey](https://github.com/DDtKey))
- Refactor check unit tests [#421] ([@mc1098](https://github.com/mc1098))
- Add missing integration tests [#420] ([@gosolivs](https://github.com/gosolivs))
- Add checker: Substitution Key [#414] ([@de-sh](https://github.com/de-sh))
- Print a message if the amount of checks doesn't match the amount of fixes [#415] ([@marcel-baur](https://github.com/marcel-baur))
- Print a message "Nothing to compare" [#398] ([@jakecorrenti](https://github.com/jakecorrenti))
- Add action-hadolint [#400] ([@iovanom](https://github.com/iovanom))
- Add method to get substitution keys to LineEntry [#391] ([@zotho](https://github.com/zotho))
- Added a Fix Benchmark [#399] ([@a4blue](https://github.com/a4blue))
- Add benchmark for the compare function [#395] ([@FrancisMurillo](https://github.com/FrancisMurillo))
- Print a message when there are no input files for fix subcommand [#394] ([@mdycz](https://github.com/mdycz))
- Print a message when there are no input files [#392] ([@jodli](https://github.com/jodli))
- Add a GitHub Action to compare benchmarks [#378] ([@mgrachev](https://github.com/mgrachev))
- Add benchmark for the check function [#376] ([@mgrachev](https://github.com/mgrachev))

### 🔧 Changed

- Refactor hard-coded mandatory fixer [#413] ([@akhtariev](https://github.com/akhtariev))
- Don't fix key order for substitution variables [#406] ([@stygian-coffee](https://github.com/stygian-coffee))
- Allow unordered keys for substitution variables [#401] ([@Ru5ty0ne](https://github.com/Ru5ty0ne))
- Replace `String` with `Into<String>` in `LineEntry::new` [#404] ([@miDeb](https://github.com/miDeb))
- Replace String on Into<String> for all TestDir methods [#397] ([@ebobrow](https://github.com/ebobrow))
- Use Rc<FileEntry> internally to reduce memory consumption [#393] ([@Tom01098](https://github.com/Tom01098))
- Use [`actions-rs/clippy-check`] to run clippy [#375] ([@mgrachev](https://github.com/mgrachev))
- Remove `Result` from the return type [#374] ([@DDtKey](https://github.com/DDtKey))
- Add `.bak` extension to backup files and don't lint backup files [#367] ([@mstruebing](https://github.com/mstruebing))
- Add `.env` explanation [#363] ([@henryboisdequin](https://github.com/henryboisdequin))
- Contemplate variables containing $ character [#418] ([@JuanMarchetto](https://github.com/JuanMarchetto))

[#428]: https://github.com/dotenv-linter/dotenv-linter/pull/428
[#421]: https://github.com/dotenv-linter/dotenv-linter/pull/421
[#420]: https://github.com/dotenv-linter/dotenv-linter/pull/420
[#418]: https://github.com/dotenv-linter/dotenv-linter/pull/418
[#415]: https://github.com/dotenv-linter/dotenv-linter/pull/415
[#414]: https://github.com/dotenv-linter/dotenv-linter/pull/414
[#413]: https://github.com/dotenv-linter/dotenv-linter/pull/413
[#406]: https://github.com/dotenv-linter/dotenv-linter/pull/406
[#404]: https://github.com/dotenv-linter/dotenv-linter/pull/404
[#401]: https://github.com/dotenv-linter/dotenv-linter/pull/401
[#400]: https://github.com/dotenv-linter/dotenv-linter/pull/400
[#399]: https://github.com/dotenv-linter/dotenv-linter/pull/399
[#398]: https://github.com/dotenv-linter/dotenv-linter/pull/398
[#397]: https://github.com/dotenv-linter/dotenv-linter/pull/397
[#395]: https://github.com/dotenv-linter/dotenv-linter/pull/395
[#394]: https://github.com/dotenv-linter/dotenv-linter/pull/394
[#393]: https://github.com/dotenv-linter/dotenv-linter/pull/393
[#392]: https://github.com/dotenv-linter/dotenv-linter/pull/392
[#391]: https://github.com/dotenv-linter/dotenv-linter/pull/391
[#378]: https://github.com/dotenv-linter/dotenv-linter/pull/378
[#376]: https://github.com/dotenv-linter/dotenv-linter/pull/376
[#375]: https://github.com/dotenv-linter/dotenv-linter/pull/375
[#374]: https://github.com/dotenv-linter/dotenv-linter/pull/374
[#367]: https://github.com/dotenv-linter/dotenv-linter/pull/367
[#363]: https://github.com/dotenv-linter/dotenv-linter/pull/363
[`actions-rs/clippy-check`]: https://github.com/actions-rs/clippy-check

## [v3.0.0] - 2021-01-11

### 🚀 Added

- Add `compare`-command [#282] ([@mstruebing](https://github.com/mstruebing))
- Add colored output feature and `--no-color` flag to disable colors [#307] ([@Nikhil0487](https://github.com/Nikhil0487))
- Display linted files when run [#311] ([@Anthuang](https://github.com/anthuang))
- Add export prefix support [#340] ([@skonik](https://github.com/skonik))
- Add colored output for compare command [#356] ([@mgrachev](https://github.com/mgrachev))

### 🔧 Changed

- Refactoring to get rid of unnecessary heap allocations and some improvements in API ergonomics [#350] ([@vbrandl](https://github.com/vbrandl))
- Add benchmark to README [#351] ([@mgrachev](https://github.com/mgrachev))
- Fix QuoteCharacterChecker to not raise warning when quote characters are used for values with whitespaces [#349] ([@sebastiantoh](https://github.com/sebastiantoh))
- Find all problems on the first run for `KeyWithoutValue` [#348] ([@vbrandl](https://github.com/vbrandl))
- Add [commitlint](https://github.com/conventional-changelog/commitlint) action [#347] ([@mgrachev](https://github.com/mgrachev))
- Add [cargo-deny](https://github.com/EmbarkStudios/cargo-deny) action [#346] ([@mgrachev](https://github.com/mgrachev))
- Remade flags to subcommands [#342] ([@mgrachev](https://github.com/mgrachev))
- Changed behavior of QuoteCharacterChecker for multiline values support [#341] ([@artem-russkikh](http://github.com/artem-russkikh))
- Make an output on-the-fly [#336] ([@DDtKey](https://github.com/DDtKey))

[#356]: https://github.com/dotenv-linter/dotenv-linter/pull/356
[#351]: https://github.com/dotenv-linter/dotenv-linter/pull/351
[#350]: https://github.com/dotenv-linter/dotenv-linter/pull/350
[#349]: https://github.com/dotenv-linter/dotenv-linter/pull/349
[#348]: https://github.com/dotenv-linter/dotenv-linter/pull/348
[#347]: https://github.com/dotenv-linter/dotenv-linter/pull/347
[#346]: https://github.com/dotenv-linter/dotenv-linter/pull/346
[#342]: https://github.com/dotenv-linter/dotenv-linter/pull/342
[#341]: https://github.com/dotenv-linter/dotenv-linter/pull/341
[#340]: https://github.com/dotenv-linter/dotenv-linter/pull/340
[#336]: https://github.com/dotenv-linter/dotenv-linter/pull/336
[#311]: https://github.com/dotenv-linter/dotenv-linter/pull/311
[#307]: https://github.com/dotenv-linter/dotenv-linter/pull/307
[#382]: https://github.com/dotenv-linter/dotenv-linter/pull/282

## [v2.2.1] - 2020-10-24

### 🚀 Added

- Add `.gitattributes` to improve `git diff` [#330] ([@DDtKey](https://github.com/DDtKey))
- Add action-yamllint [#317] ([@vk26](https://github.com/vk26))
- Add default exclude list [#324] ([@ametalon](https://github.com/ametalon))

### 🔧 Changed

- Fix bug where symlinks would cycle in recursive mode [#328] ([@sonro](https://github.com/sonro))
- Fix linter rechecking files if they were listed more than once [#327] ([@Aashu23](https://github.com/Aashu23))
- Added docker build step to the CI pipeline [#322] ([@JoeAmedeo](https://github.com/JoeAmedeo))
- Change soon deprecated `set-env` action [#320] ([@marcodenisi](https://github.com/marcodenisi))
- Fix docker release [#319] ([@mgrachev](https://github.com/mgrachev))

[#330]: https://github.com/dotenv-linter/dotenv-linter/pull/330
[#328]: https://github.com/dotenv-linter/dotenv-linter/pull/328
[#327]: https://github.com/dotenv-linter/dotenv-linter/pull/327
[#324]: https://github.com/dotenv-linter/dotenv-linter/pull/324
[#322]: https://github.com/dotenv-linter/dotenv-linter/pull/322
[#320]: https://github.com/dotenv-linter/dotenv-linter/pull/320
[#319]: https://github.com/dotenv-linter/dotenv-linter/pull/319
[#317]: https://github.com/dotenv-linter/dotenv-linter/pull/317

## [v2.2.0] - 2020-10-12

### 🚀 Added

- Add integration test for autofix [#309] ([@evgeniy-r](https://github.com/evgeniy-r))
- Add action-misspell [#304] ([@PurpleMyst](https://github.com/PurpleMyst))
- Add action-shellcheck [#303] ([@amd-9](https://github.com/amd-9))
- Add fixer: UnorderedKeyFixer [#261] ([@evgeniy-r](https://github.com/evgeniy-r))
- Add backup feature and `--no-backup` flag for fixers [#272] ([@baile320](https://github.com/baile320))
- Add fixer: ExtraBlankLineFixer [#260] ([@diggymo](https://github.com/diggymo))
- Add fixer: DuplicatedKeyFixer [#270] ([@utter-step](https://github.com/utter-step))
- Add fixer: LeadingCharacter [#259] ([@baile320](https://github.com/baile320))
- Add fixer: IncorrectDelimiter [#258] ([@gillespiecd](https://github.com/gillespiecd))
- Add support of comments to disable checks [#239] ([@mgrachev](https://github.com/mgrachev))
- Add autofix for EndingBlankLine [#263] ([@baile320](https://github.com/baile320))
- Add test for two keys that only differ in case [#269] ([@yanakad](https://github.com/yanakad))
- Add autofix for TrailingWhitespace [#255] ([@gregcline](https://github.com/gregcline))
- Add fixer: KeyWithoutValueFixer [#254] ([@unexge](https://github.com/unexge))
- Add fixer: QuoteCharacterFixer [#257] ([@lensvol](https://github.com/lensvol))
- Add fixer: SpaceCharacterFixer [#253] ([@DDtKey](https://github.com/DDtKey))
- Add total problems to output and `--quiet` argument [#242] ([@wesleimp](https://github.com/wesleimp), [@mgrachev](https://github.com/mgrachev))
- Add autofix feature (for LowercaseKey check) [#228] ([@evgeniy-r](https://github.com/evgeniy-r))
- Add installation CI test for Windows (via `install.sh`) [#235] ([@DDtKey](https://github.com/DDtKey))

### 🔧 Changed

- Update docs [#315] ([@mgrachev](https://github.com/mgrachev))
- Remove `CARGO_TERM_COLOR` from the shellcheck workflow [#313] ([@MusiKid](https://github.com/MusiKid))
- Add `check_output` helper function for integration tests [#305] ([@Anthuang](https://github.com/anthuang))
- Add an additional test for `LineEntry.get_value` [#306] ([@vvkpd](https://github.com/vvkpd))
- Update args help [#299] ([@mgrachev](https://github.com/mgrachev))
- Move `remove_invalid_leading_chars_test` to `tests` module [#298] ([@mgrachev](https://github.com/mgrachev))
- Add command to install latest version via `Homebrew` [#297] ([@mgrachev](https://github.com/mgrachev))
- Add `CARGO_TERM_COLOR` env variable to the actions [#296] ([@skippednote](https://github.com/skippednote))
- Remove code related to "Fixed/Unfixed warnings" [#289] ([@mgrachev](https://github.com/mgrachev))
- Refactoring integration tests [#288] ([@mgrachev](https://github.com/mgrachev))
- Fix a bug with fixers spawning new warnings [#287] ([@evgeniy-r](https://github.com/evgeniy-r))
- Fix a bug with `UnorderedKeyChecker` and control comments [#283] ([@mgrachev](https://github.com/mgrachev))
- Change the line grouping for the `UnorderedKey` checker [#281] ([@evgeniy-r](https://github.com/evgeniy-r))
- Fix a bug with `ExtraBlankLineFixer` and control comments [#279] ([@mgrachev](https://github.com/mgrachev))
- Move logic for creating `LineEntry` for tests to `common` module [#280] ([@mgrachev](https://github.com/mgrachev))
- Simplify UnorderedKeyChecker [#277] ([@mgrachev](https://github.com/mgrachev))
- Partition fixed/unfixed warnings [#275] ([@gillespiecd](https://github.com/gillespiecd))
- Add missing test for IncorrectDelimiterChecker [#273] ([@mgrachev](https://github.com/mgrachev))
- Add *.env to gitignore [#271] ([@baile320](https://github.com/baile320))
- Actions uses cache@v2 [#262] ([@gillespiecd](https://github.com/gillespiecd))
- Update logic for IncorrectDelimiterCheck [#267] ([@baile320](https://github.com/baile320))
- Add tests for default implementation of Fix::fix_warnings [#266] ([@kilotaras](https://github.com/kilotaras))
- Modularize common.rs [#264] ([@gillespiecd](https://github.com/gillespiecd))

[#315]: https://github.com/dotenv-linter/dotenv-linter/pull/315
[#313]: https://github.com/dotenv-linter/dotenv-linter/pull/313
[#309]: https://github.com/dotenv-linter/dotenv-linter/pull/309
[#306]: https://github.com/dotenv-linter/dotenv-linter/pull/306
[#305]: https://github.com/dotenv-linter/dotenv-linter/pull/305
[#304]: https://github.com/dotenv-linter/dotenv-linter/pull/304
[#303]: https://github.com/dotenv-linter/dotenv-linter/pull/303
[#299]: https://github.com/dotenv-linter/dotenv-linter/pull/299
[#298]: https://github.com/dotenv-linter/dotenv-linter/pull/298
[#297]: https://github.com/dotenv-linter/dotenv-linter/pull/297
[#296]: https://github.com/dotenv-linter/dotenv-linter/pull/296
[#289]: https://github.com/dotenv-linter/dotenv-linter/pull/289
[#288]: https://github.com/dotenv-linter/dotenv-linter/pull/288
[#287]: https://github.com/dotenv-linter/dotenv-linter/pull/287
[#283]: https://github.com/dotenv-linter/dotenv-linter/pull/283
[#281]: https://github.com/dotenv-linter/dotenv-linter/pull/281
[#280]: https://github.com/dotenv-linter/dotenv-linter/pull/280
[#279]: https://github.com/dotenv-linter/dotenv-linter/pull/279
[#277]: https://github.com/dotenv-linter/dotenv-linter/pull/277
[#275]: https://github.com/dotenv-linter/dotenv-linter/pull/275
[#273]: https://github.com/dotenv-linter/dotenv-linter/pull/273
[#272]: https://github.com/dotenv-linter/dotenv-linter/pull/272
[#271]: https://github.com/dotenv-linter/dotenv-linter/pull/271
[#270]: https://github.com/dotenv-linter/dotenv-linter/pull/270
[#269]: https://github.com/dotenv-linter/dotenv-linter/pull/269
[#267]: https://github.com/dotenv-linter/dotenv-linter/pull/267
[#266]: https://github.com/dotenv-linter/dotenv-linter/pull/266
[#264]: https://github.com/dotenv-linter/dotenv-linter/pull/264
[#263]: https://github.com/dotenv-linter/dotenv-linter/pull/263
[#262]: https://github.com/dotenv-linter/dotenv-linter/pull/262
[#261]: https://github.com/dotenv-linter/dotenv-linter/pull/261
[#260]: https://github.com/dotenv-linter/dotenv-linter/pull/260
[#259]: https://github.com/dotenv-linter/dotenv-linter/pull/259
[#258]: https://github.com/dotenv-linter/dotenv-linter/pull/258
[#257]: https://github.com/dotenv-linter/dotenv-linter/pull/257
[#255]: https://github.com/dotenv-linter/dotenv-linter/pull/255
[#254]: https://github.com/dotenv-linter/dotenv-linter/pull/254
[#253]: https://github.com/dotenv-linter/dotenv-linter/pull/253
[#242]: https://github.com/dotenv-linter/dotenv-linter/pull/242
[#239]: https://github.com/dotenv-linter/dotenv-linter/pull/239
[#235]: https://github.com/dotenv-linter/dotenv-linter/pull/235
[#228]: https://github.com/dotenv-linter/dotenv-linter/pull/228

## [v2.1.0] - 2020-07-13

### 🚀 Added

- Add install.sh for provide more short way to install [#220] ([@DDtKey](https://github.com/DDtKey))
- Add flag to enable recursive search for `.env` files [#223] ([@DDtKey](https://github.com/DDtKey))
- Add docs [#226] ([@wesleimp](https://github.com/wesleimp))
- Add Windows publishing to release workflow [#211] ([@DDtKey](https://github.com/DDtKey))
- Add support canonicalize path for Windows [#213] ([@DDtKey](https://github.com/DDtKey))
- Add build and test steps running on Windows [#216] ([@mgrachev](https://github.com/mgrachev))

### 🔧 Changed

- Add the field with a checker name to Warning [#234] ([@evgeniy-r](https://github.com/evgeniy-r))
- Remove `FileEntry::get_content_by_path` in favor of `fs::read_to_string` [#233] ([@mstruebing](https://github.com/mstruebing))
- Move show-checks flag to main.rs [#227] ([@mgrachev](https://github.com/mgrachev))
- Fix `total_lines` in some tests [#224] ([@DDtKey](https://github.com/DDtKey))
- Consider blank lines in `UnorderedKey` check [#221] ([@mgrachev](https://github.com/mgrachev))
- Optimize integration tests [#218] ([@mgrachev](https://github.com/mgrachev))

[#234]: https://github.com/dotenv-linter/dotenv-linter/pull/234
[#233]: https://github.com/dotenv-linter/dotenv-linter/pull/233
[#227]: https://github.com/dotenv-linter/dotenv-linter/pull/227
[#226]: https://github.com/dotenv-linter/dotenv-linter/pull/226
[#224]: https://github.com/dotenv-linter/dotenv-linter/pull/224
[#223]: https://github.com/dotenv-linter/dotenv-linter/pull/223
[#221]: https://github.com/dotenv-linter/dotenv-linter/pull/221
[#220]: https://github.com/dotenv-linter/dotenv-linter/pull/220
[#218]: https://github.com/dotenv-linter/dotenv-linter/pull/218
[#216]: https://github.com/dotenv-linter/dotenv-linter/pull/216
[#213]: https://github.com/dotenv-linter/dotenv-linter/pull/213
[#211]: https://github.com/dotenv-linter/dotenv-linter/pull/211

## [v2.0.0] - 2020-06-15

### 🚀 Added

- Add check: TrailingWhitespace [#190] ([@pineapplethief](https://github.com/pineapplethief))
- Add an argument to show available checks [#202] ([@DDtKey](https://github.com/DDtKey))
- Add the ability to skip checks [#178] ([@mgrachev](https://github.com/mgrachev))
- Add check: ExtraBlankLine [#180] ([@evgeniy-r](https://github.com/evgeniy-r))
- Add check: EndingBlankLine [#170] ([@evgeniy-r](https://github.com/evgeniy-r))
- Add check: Quote characters [#174] ([@sourabhmarathe](https://github.com/sourabhmarathe))
- Github Actions: Add caching in the CI workflow [#163] ([@evgeniy-r](https://github.com/evgeniy-r))
- Add GitHub Workflow for AUR publishing [#161] ([@mstruebing](https://github.com/mstruebing))

### 🔧 Changed

- Enable checks for outside current directory [#209] ([@tisorlawan](https://github.com/tisorlawan))
- Refactor `EndingBlankLineChecker`: change last line check logic (add `total_lines` to `FileEntry`) [#207] ([@DDtKey](https://github.com/DDtKey))
- Fix check (for several successive blank lines): ExtraBlankLine [#208] ([@evgeniy-r](https://github.com/evgeniy-r))
- Replace `PathBuf` with `FileEntry` for `LineEntry` [#203] ([@mgrachev](https://github.com/mgrachev))
- Replace `&'static str` with `&'a str` for `LeadingCharacterChecker` [#200] ([@rossjones](https://github.com/rossjones))
- Replace `&'static str` with `&'a str` for `QuoteCharacterChecker` [#198] ([@duncandean](https://github.com/duncandean))
- Replace `&'static str` with `&'a str` for `EndingBlankLineChecker` [#197] ([@rossjones](https://github.com/rossjones))
- Replace `String` with `&'a str` for `UnorderedKeyChecker` [#196] ([@k0va1](https://github.com/k0va1))
- Replace `String` with `&'a str` for `SpaceCharacterChecker` [#195] ([@k0va1](https://github.com/k0va1))
- Replace `String` with `&'a str` for `LowercaseKeyChecker` [#194] ([@tisorlawan](https://github.com/tisorlawan))
- Replace `&'static str` with `&'a str` for `ExtraBlankLineChecker` [#193] ([@vishalsodani](https://github.com/vishalsodani))
- Replace `String` with `&'a str` for `DuplicatedKeyChecker` [#192] ([@iamsaquib](https://github.com/iamsaquib))
- Replace `String` with `&'a str` for `KeyWithoutValueChecker` [#177] ([@mgrachev](https://github.com/mgrachev))
- Fix docker image [#160] ([@mgrachev](https://github.com/mgrachev))
- Replace `&'static str` with `&'a str` for `IncorrectDelimiterChecker` [#191] ([@DDtKey](https://github.com/DDtKey))

[#209]: https://github.com/dotenv-linter/dotenv-linter/pull/209
[#208]: https://github.com/dotenv-linter/dotenv-linter/pull/208
[#207]: https://github.com/dotenv-linter/dotenv-linter/pull/207
[#203]: https://github.com/dotenv-linter/dotenv-linter/pull/203
[#202]: https://github.com/dotenv-linter/dotenv-linter/pull/202
[#200]: https://github.com/dotenv-linter/dotenv-linter/pull/200
[#198]: https://github.com/dotenv-linter/dotenv-linter/pull/198
[#197]: https://github.com/dotenv-linter/dotenv-linter/pull/197
[#196]: https://github.com/dotenv-linter/dotenv-linter/pull/196
[#195]: https://github.com/dotenv-linter/dotenv-linter/pull/195
[#194]: https://github.com/dotenv-linter/dotenv-linter/pull/194
[#193]: https://github.com/dotenv-linter/dotenv-linter/pull/193
[#192]: https://github.com/dotenv-linter/dotenv-linter/pull/192
[#191]: https://github.com/dotenv-linter/dotenv-linter/pull/191
[#190]: https://github.com/dotenv-linter/dotenv-linter/pull/190
[#180]: https://github.com/dotenv-linter/dotenv-linter/pull/180
[#178]: https://github.com/dotenv-linter/dotenv-linter/pull/179
[#177]: https://github.com/dotenv-linter/dotenv-linter/pull/177
[#174]: https://github.com/dotenv-linter/dotenv-linter/pull/174
[#170]: https://github.com/dotenv-linter/dotenv-linter/pull/170
[#163]: https://github.com/dotenv-linter/dotenv-linter/pull/163
[#161]: https://github.com/dotenv-linter/dotenv-linter/pull/161
[#160]: https://github.com/dotenv-linter/dotenv-linter/pull/160

## [v1.2.0] - 2020-04-20

### 🔧 Changed

- SpaceCharacter: Show check name in the message [#149] ([@pineapplethief](https://github.com/pineapplethief))
- LeadingCharacter: Show check name in message [#144] ([@michaetto](https://github.com/michaetto))
- Rename `UnorderedKeys` check to singular `UnorderedKey` [#147] ([@pineapplethief](https://github.com/pineapplethief))
- KeyWithoutValue: Show check name in the message [#139] ([@harshu4](https://github.com/harshu4))
- LowercaseKey: Show check name in the message [#131] ([@qelphybox](https://github.com/qelphybox))
- DuplicatedKey: Show check name in message [#138] ([@SaMuRa1ReM1X](https://github.com/SaMuRa1ReM1X))
- IncorrectDelimiter: Show check name in the message [#146] ([@undef1nd](https://github.com/undef1nd))
- Replaced kcov with grcov in Github Actions [#143] ([@pmk21](https://github.com/pmk21))
- Streamline CLI tests and split into smaller files [#137] ([@sonro](https://github.com/sonro))
- UnorderedKey: Added check name to the message [#140] ([@pmk21](https://github.com/pmk21))
- Add test coverage for CLI --exclude arguments [#135] ([@sonro](https://github.com/sonro))
- Renamed check SpacesAroundEqual to SpaceCharacter [#134] ([@SaMuRa1ReM1X](https://github.com/SaMuRa1ReM1X))
- Rename check DuplicatedKeys to DuplicatedKey [#133] ([@sonro](https://github.com/sonro))
- Minimizing Rust Binary Size [#132] ([@akirill0v](https://github.com/akirill0v))
- Remove the unwrap method and use platform native OsString to fetch the information about current directory [#115] ([@kanapuli](https://github.com/kanapuli))
- Use HashSet for DuplicateKeyChecker [#113] ([@TamasFlorin](https://github.com/TamasFlorin))
- Use reference for the LineEntry as part of the run method for checks [#111] ([@TamasFlorin](https://github.com/TamasFlorin))
- New CLI API: Ability to check multiple directories [#99] ([@mgrachev](https://github.com/mgrachev))
- Add exit with the code 0 when there are no warnings [#105] ([@simPod](https://github.com/simPod))
- Use `get` method to get result of item in `Vec` and use ? operator unwrap the result if it's `Some` [#108] ([@boybird](https://github.com/boybird))

[#149]: https://github.com/dotenv-linter/dotenv-linter/pull/149
[#147]: https://github.com/dotenv-linter/dotenv-linter/pull/147
[#146]: https://github.com/dotenv-linter/dotenv-linter/pull/146
[#140]: https://github.com/dotenv-linter/dotenv-linter/pull/140
[#139]: https://github.com/dotenv-linter/dotenv-linter/pull/139
[#138]: https://github.com/dotenv-linter/dotenv-linter/pull/138
[#137]: https://github.com/dotenv-linter/dotenv-linter/pull/137
[#135]: https://github.com/dotenv-linter/dotenv-linter/pull/135
[#134]: https://github.com/dotenv-linter/dotenv-linter/pull/134
[#133]: https://github.com/dotenv-linter/dotenv-linter/pull/133
[#132]: https://github.com/dotenv-linter/dotenv-linter/pull/132
[#131]: https://github.com/dotenv-linter/dotenv-linter/pull/131
[#115]: https://github.com/dotenv-linter/dotenv-linter/pull/115
[#113]: https://github.com/dotenv-linter/dotenv-linter/pull/113
[#111]: https://github.com/dotenv-linter/dotenv-linter/pull/111
[#108]: https://github.com/dotenv-linter/dotenv-linter/pull/108
[#105]: https://github.com/dotenv-linter/dotenv-linter/pull/105
[#99]: https://github.com/dotenv-linter/dotenv-linter/pull/99

## [v1.1.2] - 2020-03-13

### 🔧 Changed

- Fix --path CLI parameter not canonizing filepaths from directory path passed as argument and not working as intended as a result [#97] ([@pineapplethief](https://github.com/pineapplethief))
- Fix incorrect delimiter check for keys contains numeric [#95] ([@alter369](https://github.com/alter369))
- Add `LineEntry.is_empty_or_comment` method to DRY and simplify `Check.run` [#94] ([@pineapplethief](https://github.com/pineapplethief))
- Refactor `Github Actions` and reduce `Docker Image size` [#90] ([@Macbet](https://github.com/Macbet))
- Use `Line.get_key` in all checks [#89] ([@pineapplethief](https://github.com/pineapplethief))

[#97]: https://github.com/dotenv-linter/dotenv-linter/pull/97
[#95]: https://github.com/dotenv-linter/dotenv-linter/pull/95
[#94]: https://github.com/dotenv-linter/dotenv-linter/pull/94
[#90]: https://github.com/dotenv-linter/dotenv-linter/pull/90
[#89]: https://github.com/dotenv-linter/dotenv-linter/pull/89

## [v1.1.1] - 2020-02-18

### 🔧 Changed

- Show the full path to the file relative to the current directory [#85] ([@mgrachev](https://github.com/mgrachev))

[#85]: https://github.com/dotenv-linter/dotenv-linter/pull/85

## [v1.1.0] - 2020-01-27

### 🚀 Added

- Add check: Unordered keys [#72] ([@mgrachev](https://github.com/mgrachev))
- Add the ability to specify the directory where to run [#65] ([@Louis-Lesage](https://github.com/Louis-Lesage))
- Add check: Duplicated keys [#33] ([@mstruebing](https://github.com/mstruebing))
- Add exit with the code 1 on warnings found [#58] ([@Louis-Lesage](https://github.com/Louis-Lesage))
- Add exclude argument to exclude specific files [#49] ([@mstruebing](https://github.com/mstruebing))
- Add the ability to include files to check [#48] ([@mgrachev](https://github.com/mgrachev))
- Add check: Spaces around equal sign [#35] ([@artem-russkikh](https://github.com/artem-russkikh))
- Add skipping of commented or empty lines [#37] ([@mstruebing](https://github.com/mstruebing))

### 🔧 Changed

- Rename `leading_space` to `leading_character` and check for allowed chars [#63] ([@mstruebing](https://github.com/mstruebing))
- Remove multiple checks of the same file [#62] ([@mstruebing](https://github.com/mstruebing))
- Add mutability support for checks [#52] ([@mgrachev](https://github.com/mgrachev))

[#72]: https://github.com/dotenv-linter/dotenv-linter/pull/72
[#65]: https://github.com/dotenv-linter/dotenv-linter/pull/65
[#63]: https://github.com/dotenv-linter/dotenv-linter/pull/63
[#62]: https://github.com/dotenv-linter/dotenv-linter/pull/62
[#58]: https://github.com/dotenv-linter/dotenv-linter/pull/58
[#52]: https://github.com/dotenv-linter/dotenv-linter/pull/52
[#49]: https://github.com/dotenv-linter/dotenv-linter/pull/49
[#48]: https://github.com/dotenv-linter/dotenv-linter/pull/48
[#37]: https://github.com/dotenv-linter/dotenv-linter/pull/37
[#35]: https://github.com/dotenv-linter/dotenv-linter/pull/35
[#33]: https://github.com/dotenv-linter/dotenv-linter/pull/33

## [v1.0.0] - 2020-01-01

### 🚀 Added

- Add check: Keys without values [#22] ([@mstruebing](https://github.com/mstruebing))
- Add check: Lowercase keys [#21] ([@qelphybox](https://github.com/qelphybox))
- Add check: Incorrect delimiter [#20] ([@sonro](https://github.com/sonro))
- Add `Display` trait for `LineEntry` [#19] ([@mstruebing](https://github.com/mstruebing))

### 🔧 Changed

- Add support for command line arguments [#31] ([@mgrachev](https://github.com/mgrachev))
- Replace field warning with template for all check structs [#26] ([@mgrachev](https://github.com/mgrachev))
- Prepare a template for easy adding new checks [#14] ([@mgrachev](https://github.com/mgrachev))

[#31]: https://github.com/dotenv-linter/dotenv-linter/pull/31
[#26]: https://github.com/dotenv-linter/dotenv-linter/pull/26
[#22]: https://github.com/dotenv-linter/dotenv-linter/pull/22
[#21]: https://github.com/dotenv-linter/dotenv-linter/pull/21
[#20]: https://github.com/dotenv-linter/dotenv-linter/pull/20
[#19]: https://github.com/dotenv-linter/dotenv-linter/pull/19
[#14]: https://github.com/dotenv-linter/dotenv-linter/pull/14
[v3.2.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v3.2.0
[v3.1.1]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v3.1.1
[v3.1.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v3.1.0
[v3.0.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v3.0.0
[v2.2.1]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v2.2.1
[v2.2.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v2.2.0
[v2.1.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v2.1.0
[v2.0.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v2.0.0
[v1.2.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v1.2.0
[v1.1.2]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v1.1.2
[v1.1.1]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v1.1.1
[v1.1.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v1.1.0
[v1.0.0]: https://github.com/dotenv-linter/dotenv-linter/releases/tag/v1.0.0
